@@ -48,6 +48,10 @@ bool dxfReader::readRec(int *codeData) {
         readInt16();
     else if (code < 300) //TODO this is a boolean indicator, int in Binary?
         readBool();
+    else if (code < 310)
+        readString();
+    else if (code < 320)
+        readBinary();
     else if (code < 370)
         readString();
     else if (code < 390)
@@ -74,6 +78,8 @@ bool dxfReader::readRec(int *codeData) {
         readString();
         return readRec( codeData);
     }
+    else if (code == 1004)
+        readBinary();
     else if (code > 998 && code < 1009) //skip not used at the v2012
         readString();
     else if (code < 1060) //TODO this is a floating point double precision??
@@ -137,6 +143,16 @@ bool dxfReaderBinary::readString(std::string *text) {
     return (filestr->good());
 }
 
+bool dxfReaderBinary::readBinary() {
+    unsigned char chunklen {0};
+
+    filestr->read( reinterpret_cast<char *>(&chunklen), 1);
+    filestr->seekg( chunklen, std::ios_base::cur);
+    DRW_DBG( chunklen); DRW_DBG( " byte(s) binary data bypassed\n");
+
+    return (filestr->good());
+}
+
 bool dxfReaderBinary::readInt16() {
     type = INT32;
     char buffer[2];
@@ -212,6 +228,10 @@ bool dxfReaderAscii::readString() {
     return (filestr->good());
 }
 
+bool dxfReaderAscii::readBinary() {
+    return readString();
+}
+
 bool dxfReaderAscii::readInt16() {
     type = INT32;
     std::string text;
