@@ -38,11 +38,6 @@
 #include "rs_preview.h"
 #include "rs_debug.h"
 
-namespace {
-auto enTypeList={RS2::EntityLine, RS2::EntityArc, RS2::EntityCircle,
-				 RS2::EntityEllipse};
-}
-
 RS_ActionDrawLineRelAngle::RS_ActionDrawLineRelAngle(
 		RS_EntityContainer& container,
 		RS_GraphicView& graphicView,
@@ -69,6 +64,11 @@ RS2::ActionType RS_ActionDrawLineRelAngle::rtti() const{
 		return RS2::ActionDrawLineRelAngle;
 }
 
+void RS_ActionDrawLineRelAngle::finish(bool updateTB) {
+    unhighlightEntity();
+    RS_PreviewActionInterface::finish(updateTB);
+}
+
 void RS_ActionDrawLineRelAngle::trigger() {
     RS_PreviewActionInterface::trigger();
 
@@ -344,4 +344,12 @@ void RS_ActionDrawLineRelAngle::updateMouseCursor()
     }
 }
 
+void RS_ActionDrawLineRelAngle::unhighlightEntity()
+{
+    if (entity) {
+        entity->setHighlighted(false);
+        graphicView->drawEntity(entity);
+    }
+}
+
 // EOF
