@@ -27,6 +27,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 #include "rs_actioninterface.h"
 
+class RS_Layer;
 
 /**
  * whether a layer should appear on print (a construction layer doesn't appear on
@@ -38,14 +39,17 @@ class RS_ActionLayersTogglePrint : public RS_ActionInterface {
     Q_OBJECT
 public:
     RS_ActionLayersTogglePrint(RS_EntityContainer& container,
-                              RS_GraphicView& graphicView);
-    ~RS_ActionLayersTogglePrint() = default;
+                              RS_GraphicView& graphicView,
+                               RS_Layer* layer);
 
-    static QAction* createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/);
+	void init(int status=0) override;
+	void trigger() override;
 
-    virtual void init(int status=0);
-    virtual void trigger();
+protected:
+    RS_Layer* a_layer;
 
+private:
+    void deselectEntities(RS_Layer* layer);
 };
 
 #endif
