@@ -22,7 +22,11 @@
 **
 ** This copyright notice MUST APPEAR in all copies of the script!  
 **
-**********************************************************************/
+** *************************************************************************
+** ChangeLog
+** *************************************************************************
+** This file was changed in 2016 by ravas. See ChangeLogs/r-a-v-a-s.txt
+****************************************************************************/
 
 #include "rs_actionlayerstoggleview.h"
 
@@ -42,7 +46,22 @@ RS_ActionLayersToggleView::RS_ActionLayersToggleView(
 void RS_ActionLayersToggleView::trigger() {
     RS_DEBUG->print("toggle layer");
     if (graphic) {
-        graphic->toggleLayer(a_layer);
+        RS_LayerList* ll = graphic->getLayerList();
+        unsigned cnt = 0;
+        // toggle selected layers
+        for (auto layer: *ll) {
+            if (!layer) continue;
+            if (!layer->isVisibleInLayerList()) continue;
+            if (!layer->isSelectedInLayerList()) continue;
+            graphic->toggleLayer(layer);
+            cnt++;
+        }
+        // if there wasn't selected layers, toggle active layer
+        if (!cnt) {
+            graphic->toggleLayer(a_layer);
+        }
+        graphic->updateInserts();
+        container->calculateBorders();
     }
     finish(false);
 }
