@@ -32,14 +32,15 @@
 #include "rs_actionselectsingle.h"
 
 
-RS_ActionSelect::RS_ActionSelect(RS_EntityContainer& container,
+RS_ActionSelect::RS_ActionSelect(QG_ActionHandler* a_handler,
+                                 RS_EntityContainer& container,
                                  RS_GraphicView& graphicView,
                                  RS2::ActionType nextAction,
 								 std::initializer_list<RS2::EntityType> const& entityTypeList)
 	:RS_ActionInterface("Select Entities", container, graphicView)
 	,entityTypeList(entityTypeList)
 	,nextAction(nextAction)
-	,selectSingle(false)
+    ,action_handler(a_handler)
 {
 	actionType=RS2::ActionSelect;
 }
@@ -58,18 +59,9 @@ void RS_ActionSelect::init(int status) {
 
 void RS_ActionSelect::resume(){
     RS_ActionInterface::resume();
-    if(selectSingle==false){
-        finish();
-    }else{
-        deleteSnapper();
-    }
+    deleteSnapper();
 }
 
-void RS_ActionSelect::requestFinish(bool keep){
-    selectSingle=keep;
-}
-
-
 void RS_ActionSelect::mouseReleaseEvent(QMouseEvent* e) {
     if (e->button()==Qt::RightButton) {
         init(getStatus()-1);
@@ -79,45 +71,12 @@ void RS_ActionSelect::mouseReleaseEvent(QMouseEvent* e) {
 
 int RS_ActionSelect::countSelected() {
         int ret=container->countSelected();
-        if(ret==0 && RS_DIALOGFACTORY){
+		if (ret==0) {
             RS_DIALOGFACTORY->commandMessage(tr("No entity selected!"));
         }
         return ret;
 }
 
-void RS_ActionSelect::updateToolBar() {
-    if (RS_DIALOGFACTORY) {
-        if (isFinished()){
-            if(container->countSelected()==0){
-                //some nextAction segfault with empty selection
-                //todo: make actions safe with empty selection, issue#235
-                RS_DIALOGFACTORY->commandMessage(tr("No entity selected!"));
-                //do not keep toolbar select after this action finishes, issue#291
-//                RS_DIALOGFACTORY->requestToolBarSelect(this, nextAction);
-                RS_DIALOGFACTORY->requestPreviousToolBar();
-            } else{
-                if ( entityTypeList.size()){
-                    //only select entity types from the given list
-                    //fixme, need to handle resolution level
-
-					for(auto e: *container){
-						if (e && e->isSelected()) {
-							if(std::find(entityTypeList.begin(),
-								     entityTypeList.end(),
-								      e->rtti()) == entityTypeList.end())
-								e->setSelected(false);
-                        }
-                    }
-                }
-                RS_DIALOGFACTORY->requestPreviousToolBar();
-            }
-        }else{
-            RS_DIALOGFACTORY->requestToolBarSelect(this, nextAction);
-        }
-
-    }
-}
-
 void RS_ActionSelect::updateMouseButtonHints() {
     switch(nextAction) {
     case RS2::ActionModifyAttributesNoSelect:
@@ -187,4 +146,14 @@ void RS_ActionSelect::updateMouseCursor() {
         }
     }
 }
+
+void RS_ActionSelect::keyPressEvent(QKeyEvent* e)
+{
+    if (e->key()==Qt::Key_Enter && countSelected() > 0)
+    {
+        finish();
+        action_handler->setCurrentAction(nextAction);
+    }
+}
+
 // EOF
