@@ -21,6 +21,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **********************************************************************/
 
+#include <QPainterPath>
 #include <QPolygonF>
 #include "lc_splinepoints.h"
 
@@ -998,7 +999,11 @@ RS_Vector LC_SplinePoints::GetSplinePointAtDist(double dDist, int iStartSeg,
 
 	if(dDist <= dQuadDist)
 	{
-		double dt = GetQuadPointAtDist(vStart, vControl, vEnd, 0.0, dDist);
+        double t0 {0.0};
+        if (static_cast<size_t>(iStartSeg + 1) == i) {
+            t0 = dStartT;
+        }
+		double dt = GetQuadPointAtDist(vStart, vControl, vEnd, t0, dDist);
 		vRes = GetQuadPoint(vStart, vControl, vEnd, dt);
 		*piSeg = i - 1;
 		*pdt = dt;
@@ -1069,7 +1074,7 @@ RS_Vector LC_SplinePoints::getNearestMiddle(const RS_Vector& coord,
     vRes = GetSplinePointAtDist(dDist, 1, 0.0, &iNext, &dt);
 	if(vRes.valid) dMinDist = (vRes - coord).magnitude();
     i = 2;
-	while(vRes.valid && i < middlePoints)
+	while(vRes.valid && i <= middlePoints)
 	{
 		vNext = GetSplinePointAtDist(dDist, iNext, dt, &iNext, &dt);
 		dCurDist = (vNext - coord).magnitude();
@@ -1908,7 +1913,7 @@ void LC_SplinePoints::draw(RS_Painter* painter, RS_GraphicView* view, double& pa
 
 	// Pattern:
 	const RS_LineTypePattern* pat = nullptr;
-	if(isSelected())
+	if(isSelected() && !(view->isPrinting() || view->isPrintPreview()))
 	{
 //		styleFactor=1.;
         pat = &RS_LineTypePattern::patternSelected;
@@ -3405,9 +3410,8 @@ RS_VectorSolutions getQuadraticLineIntersect(std::vector<double> dQuadCoefs,
 	{
         if(d > -RS_TOLERANCE && d < 1.0 + RS_TOLERANCE)
 		{
-            if(d < 0.0) d = 0.0;
-            if(d > 1.0) d = 1.0;
-			ret.push_back(vx1*(1.0 - d) + vx2*d);
+            d = qBound(0.0, d, 1.0);
+            ret.push_back(vx1*(1.0 - d) + vx2*d);
 		}
 	}
 
@@ -3479,15 +3483,17 @@ void addQuadraticQuadIntersect(RS_VectorSolutions *pVS, std::vector<double> dQua
 		dSol.push_back(-a0/a1);
 	}
 
-    for(double& d: dSol)
-	{
-        if(d > -RS_TOLERANCE && d < 1.0 + RS_TOLERANCE)
-		{
-            if(d < 0.0) d = 0.0;
-            if(d > 1.0) d = 1.0;
-			pVS->push_back(GetQuadAtPoint(vx1, vc1, vx2, d));
-		}
-	}
+    for (double& d: dSol) {
+        if (d > -RS_TOLERANCE && d < 1.0 + RS_TOLERANCE) {
+            if (d < 0.0) {
+                d = 0.0;
+            }
+            if (d > 1.0) {
+                d = 1.0;
+            }
+            pVS->push_back(GetQuadAtPoint(vx1, vc1, vx2, d));
+        }
+    }
 }
 
 RS_VectorSolutions LC_SplinePoints::getQuadraticIntersect(RS_Entity const* e1)
