@@ -127,7 +127,7 @@ bool RS_Arc::createFrom3P(const RS_Vector& p1, const RS_Vector& p2,
  * and radius.
  *
  * @retval true Successfully created arc
- * @retval false Cannot creats arc (radius to small or endpoint to far away)
+ * @retval false Cannot create arc (radius to small or endpoint to far away)
  */
 bool RS_Arc::createFrom2PDirectionRadius(const RS_Vector& startPoint,
         const RS_Vector& endPoint,
@@ -162,7 +162,7 @@ bool RS_Arc::createFrom2PDirectionRadius(const RS_Vector& startPoint,
  * and angle length.
  *
  * @retval true Successfully created arc
- * @retval false Cannot creats arc (radius to small or endpoint to far away)
+ * @retval false Cannot create arc (radius to small or endpoint to far away)
  */
 bool RS_Arc::createFrom2PDirectionAngle(const RS_Vector& startPoint,
                                         const RS_Vector& endPoint,
@@ -555,8 +555,10 @@ RS_Vector RS_Arc::getNearestOrthTan(const RS_Vector& coord,
                                 vp=sol[1];
                                 break;
                         }
+                        // fall-through
                 default:
                         vp=sol[0];
+                        break;
         }
         return getCenter()+vp;
 }
@@ -690,7 +692,7 @@ RS_Vector RS_Arc::prepareTrim(const RS_Vector& trimCoord,
             }
         }
         std::sort(ias.begin(),ias.end());
-		for(size_t ii=0; ii<trimSol.getNumber(); ++ii) { //find segment to enclude trimCoord
+		for(size_t ii=0; ii<trimSol.getNumber(); ++ii) { //find segment to include trimCoord
             if ( ! RS_Math::isSameDirection(ia,ias[ii],RS_TOLERANCE)) continue;
             if( RS_Math::isAngleBetween(am,ias[(ii+trimSol.getNumber()-1)% trimSol.getNumber()],ia,false))  {
                 ia2=ias[(ii+trimSol.getNumber()-1)% trimSol.getNumber()];
@@ -699,7 +701,7 @@ RS_Vector RS_Arc::prepareTrim(const RS_Vector& trimCoord,
             }
             break;
         }
-		for(const RS_Vector& vp: trimSol) { //find segment to enclude trimCoord
+		for(const RS_Vector& vp: trimSol) { //find segment to include trimCoord
 			if ( ! RS_Math::isSameDirection(ia2,getArcAngle(vp),RS_TOLERANCE)) continue;
 			is2=vp;
             break;
@@ -950,7 +952,7 @@ void RS_Arc::drawVisible(RS_Painter* painter, RS_GraphicView* view,
                   double& patternOffset) {
 
 	if (!( painter && view)) return;
-    //visible in grahic view
+    //visible in graphic view
     if(isVisibleInWindow(view)==false) return;
 
     RS_Vector cp=view->toGui(getCenter());
@@ -959,8 +961,10 @@ void RS_Arc::drawVisible(RS_Painter* painter, RS_GraphicView* view,
     //double styleFactor = getStyleFactor();
     patternOffset -= length;
 
+    bool drawAsSelected = isSelected() && !(view->isPrinting() || view->isPrintPreview());
+
     // simple style-less lines
-    if ( !isSelected() && (
+    if ( !drawAsSelected && (
              getPen().getLineType()==RS2::SolidLine ||
              view->getDrawingMode()==RS2::ModePreview)) {
         painter->drawArc(cp,
@@ -980,7 +984,8 @@ void RS_Arc::drawVisible(RS_Painter* painter, RS_GraphicView* view,
 
     // Pattern:
     const RS_LineTypePattern* pat;
-    if (isSelected()) {
+    if (drawAsSelected)
+    {
         pat = &RS_LineTypePattern::patternSelected;
     } else {
         pat = view->getPattern(getPen().getLineType());
@@ -1034,7 +1039,7 @@ void RS_Arc::drawVisible(RS_Painter* painter, RS_GraphicView* view,
 	double a1{RS_Math::correctAngle(getAngle1())};
 	double a2{RS_Math::correctAngle(getAngle2())};
 
-    if(isReversed()) {//always draw from a1 to a2, so, patternOffset is is automatic
+    if(isReversed()) {//always draw from a1 to a2, so, patternOffset is automatic
         if(a1<a2+RS_TOLERANCE_ANGLE) a2 -= 2.*M_PI;
         total = a1 - total*ira; //in angle
     }else{
