@@ -53,6 +53,11 @@ int RS_Math::round(double v) {
     return (int) lrint(v);
 }
 
+double RS_Math::round(const double v, const double precision)
+{
+    return precision * llround(v / precision);
+}
+
 /**
  * Save pow function
  */
@@ -77,6 +82,14 @@ RS_Vector RS_Math::pow(RS_Vector vp, double y) {
     return RS_Vector(pow(vp.x,y),pow(vp.y,y));
 }
 
+/**
+ * Save equal function for real types
+ */
+bool RS_Math::equal(const double d1, const double d2)
+{
+    return fabs(d1 - d2) < RS_TOLERANCE;
+}
+
 /**
  * Converts radians to degrees.
  */
@@ -140,12 +153,22 @@ bool RS_Math::isAngleBetween(double a,
 }
 
 /**
- * Corrects the given angle to the range of 0-2*Pi.
+ * Corrects the given angle to the range of 0 to +PI*2.0.
  */
 double RS_Math::correctAngle(double a) {
-    return M_PI + remainder(a - M_PI, m_piX2);
+    return fmod(M_PI + remainder(a - M_PI, m_piX2), m_piX2);
 }
 
+/**
+ * Corrects the given angle to the range of -PI to +PI.
+ */
+double RS_Math::correctAngle2(double a) {
+    return remainder(a, m_piX2);
+}
+
+/**
+ * Returns the given angle as an Unsigned Angle in the range of 0 to +PI.
+ */
 double RS_Math::correctAngleU(double a) {
     return fabs(remainder(a, m_piX2));
 }
@@ -223,7 +246,7 @@ bool RS_Math::isSameDirection(double dir1, double dir2, double tol) {
 
 /**
  * Evaluates a mathematical expression and returns the result.
- * If an error occured, the given default value 'def' will be returned.
+ * If an error occurred, the given default value 'def' will be returned.
  */
 double RS_Math::eval(const QString& expr, double def) {
 
@@ -242,7 +265,7 @@ double RS_Math::eval(const QString& expr, double def) {
 
 /**
  * Evaluates a mathematical expression and returns the result.
- * If an error occured, ok will be set to false (if ok isn't NULL).
+ * If an error occurred, ok will be set to false (if ok isn't NULL).
  */
 double RS_Math::eval(const QString& expr, bool* ok) {
     bool okTmp(false);
@@ -254,14 +277,18 @@ double RS_Math::eval(const QString& expr, bool* ok) {
     double ret(0.);
     try{
         mu::Parser p;
-        p.DefineConst("pi",M_PI);
+        p.DefineConst(_T("pi"),M_PI);
+#ifdef _UNICODE
+        p.SetExpr(expr.toStdWString());
+#else
         p.SetExpr(expr.toStdString());
+#endif
         ret=p.Eval();
         *ok=true;
     }
     catch (mu::Parser::exception_type &e)
     {
-        std::cout << e.GetMsg() << std::endl;
+        mu::console() << e.GetMsg() << std::endl;
         *ok=false;
     }
     return ret;
@@ -408,7 +435,7 @@ void RS_Math::test() {
 //Equation solvers
 
 // quadratic, cubic, and quartic equation solver
-// @ ce[] contains coefficent of the cubic equation:
+// @ ce[] contains coefficient of the cubic equation:
 // @ returns a vector contains real roots
 //
 // solvers assume arguments are valid, and there's no attempt to verify validity of the argument pointers
