@@ -43,16 +43,19 @@ public slots:
     virtual void setFocus();
     virtual void setCommand( const QString & cmd );
     virtual void appendHistory( const QString & msg );
-    virtual void trigger();
+    virtual void handleCommand(QString cmd);
+    virtual void handleKeycode(QString code);
     virtual void tabPressed();
     virtual void escape();
     virtual void setActionHandler( QG_ActionHandler * ah );
     virtual void setCommandMode();
     virtual void setNormalMode();
 	static QString getRootCommand( const QStringList & cmdList, const QString & typed );
+    void setKeycodeMode(bool state);
 
 protected slots:
     virtual void languageChange();
+    virtual void chooseCommandFile();
 
 private:
     QG_ActionHandler* actionHandler;
