@@ -77,6 +77,7 @@
 #include "rs_actiondrawlineparallelthrough.h"
 #include "rs_actiondrawlinepolygon.h"
 #include "rs_actiondrawlinepolygon2.h"
+#include "lc_actiondrawlinepolygon3.h"
 #include "rs_actiondrawlinerectangle.h"
 #include "rs_actiondrawlinerelangle.h"
 #include "rs_actiondrawlineorthtan.h"
@@ -103,6 +104,7 @@
 #include "rs_actionlayersadd.h"
 #include "rs_actionlayersedit.h"
 #include "rs_actionlayersfreezeall.h"
+#include "rs_actionlayerslockall.h"
 #include "rs_actionlayersremove.h"
 #include "rs_actionlayerstogglelock.h"
 #include "rs_actionlayerstoggleview.h"
@@ -165,6 +167,7 @@
 #include "qg_snaptoolbar.h"
 #include "rs_debug.h"
 #include "rs_layer.h"
+#include "rs_settings.h"
 
 /**
  * Constructor
@@ -216,6 +219,9 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
     RS_ActionInterface* a = NULL;
 //    view->killAllActions();
 
+    RS_DEBUG->print("QC_ActionHandler::setCurrentAction: "
+            "view = %p, document = %p", view, document);
+
     // only global options are allowed without a document:
     if (view==NULL || document==NULL) {
         RS_DEBUG->print(RS_Debug::D_WARNING,
@@ -275,6 +281,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			a = new RS_ActionSelect(this, *document, *view, RS2::ActionEditCutNoSelect);
 			break;
 		}
+        // fall-through
     case RS2::ActionEditCutNoSelect:
         a = new RS_ActionEditCopy(false, *document, *view);
         break;
@@ -283,6 +290,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			a = new RS_ActionSelect(this, *document, *view, RS2::ActionEditCopyNoSelect);
 			break;
 		}
+        // fall-through
     case RS2::ActionEditCopyNoSelect:
         a = new RS_ActionEditCopy(true, *document, *view);
         break;
@@ -291,7 +299,12 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
         break;
     case RS2::ActionOrderBottom:
         orderType = RS2::ActionOrderBottom;
-        a = new RS_ActionSelect(this, *document, *view, RS2::ActionOrderNoSelect);
+        if(!document->countSelected()){
+            a = new RS_ActionSelect(this, *document, *view, RS2::ActionOrderNoSelect);
+        }
+        else {
+            a = new RS_ActionOrder(*document, *view, orderType);
+        }
         break;
     case RS2::ActionOrderLower:
         orderType = RS2::ActionOrderLower;
@@ -302,11 +315,14 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
         a = new RS_ActionSelect(this, *document, *view, RS2::ActionOrderNoSelect);
         break;
     case RS2::ActionOrderTop:
-		if(!document->countSelected()){
-			orderType = RS2::ActionOrderTop;
-			a = new RS_ActionSelect(this, *document, *view, RS2::ActionOrderNoSelect);
-			break;
-		}
+        orderType = RS2::ActionOrderTop;
+        if(!document->countSelected()){
+            a = new RS_ActionSelect(this, *document, *view, RS2::ActionOrderNoSelect);
+        }
+        else {
+            a = new RS_ActionOrder(*document, *view, orderType);
+        }
+        break;
     case RS2::ActionOrderNoSelect:
         a = new RS_ActionOrder(*document, *view, orderType);
         break;
@@ -465,6 +481,9 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
     case RS2::ActionDrawLinePolygonCenCor:
         a = new RS_ActionDrawLinePolygonCenCor(*document, *view);
         break;
+    case RS2::ActionDrawLinePolygonCenTan:                      //20161223 added by txmy
+        a = new LC_ActionDrawLinePolygonCenTan(*document, *view);
+        break;
     case RS2::ActionDrawLinePolygonCorCor:
         a = new RS_ActionDrawLinePolygonCorCor(*document, *view);
         break;
@@ -553,6 +572,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
             a = new RS_ActionSelect(this, *document, *view, RS2::ActionDrawHatchNoSelect);
             break;
         }
+        // fall-through
 	case RS2::ActionDrawHatchNoSelect:
 		a = new RS_ActionDrawHatch(*document, *view);
         break;   
@@ -594,6 +614,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			a = new RS_ActionSelect(this, *document, *view, RS2::ActionModifyAttributesNoSelect);
 			break;
 		}
+        // fall-through
     case RS2::ActionModifyAttributesNoSelect:
         a = new RS_ActionModifyAttributes(*document, *view);
         break;
@@ -614,6 +635,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			a = new RS_ActionSelect(this, *document, *view, RS2::ActionModifyMoveNoSelect);
 			break;
 		}
+        // fall-through
     case RS2::ActionModifyMoveNoSelect:
         a = new RS_ActionModifyMove(*document, *view);
         break;
@@ -622,6 +644,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			a = new RS_ActionSelect(this, *document, *view, RS2::ActionModifyRevertDirectionNoSelect);
 			break;
 		}
+		// fall-through
 	case RS2::ActionModifyRevertDirectionNoSelect:
 		a = new RS_ActionModifyRevertDirection(*document, *view);
 		break;
@@ -630,6 +653,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			a = new RS_ActionSelect(this, *document, *view, RS2::ActionModifyRotateNoSelect);
 			break;
 		}
+        // fall-through
     case RS2::ActionModifyRotateNoSelect:
         a = new RS_ActionModifyRotate(*document, *view);
         break;
@@ -638,6 +662,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			a = new RS_ActionSelect(this, *document, *view, RS2::ActionModifyScaleNoSelect);
 			break;
 		}
+        // fall-through
     case RS2::ActionModifyScaleNoSelect:
 		a = new RS_ActionModifyScale(*document, *view);
 		break;
@@ -646,6 +671,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			a = new RS_ActionSelect(this, *document, *view, RS2::ActionModifyMirrorNoSelect);
 			break;
 		}
+        // fall-through
     case RS2::ActionModifyMirrorNoSelect:
         a = new RS_ActionModifyMirror(*document, *view);
         break;
@@ -654,6 +680,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			a = new RS_ActionSelect(this, *document, *view, RS2::ActionModifyMoveRotateNoSelect);
 			break;
 		}
+        // fall-through
     case RS2::ActionModifyMoveRotateNoSelect:
         a = new RS_ActionModifyMoveRotate(*document, *view);
         break;
@@ -662,6 +689,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			a = new RS_ActionSelect(this, *document, *view, RS2::ActionModifyRotate2NoSelect);
 			break;
 		}
+        // fall-through
     case RS2::ActionModifyRotate2NoSelect:
         a = new RS_ActionModifyRotate2(*document, *view);
 		break;
@@ -699,6 +727,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			break;
 		}
 	}
+    // fall-through
     case RS2::ActionModifyOffsetNoSelect:
         a = new RS_ActionModifyOffset(*document, *view);
 		break;
@@ -707,6 +736,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			a = new RS_ActionSelect(this, *document, *view, RS2::ActionModifyExplodeTextNoSelect);
 			break;
 		}
+        // fall-through
     case RS2::ActionModifyExplodeTextNoSelect:
         a = new RS_ActionModifyExplodeText(*document, *view);
         break;
@@ -799,6 +829,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			a = new RS_ActionSelect(this, *document, *view, RS2::ActionInfoTotalLengthNoSelect);
 			break;
 		}
+        // fall-through
     case RS2::ActionInfoTotalLengthNoSelect:
         a = new RS_ActionInfoTotalLength(*document, *view);
         break;
@@ -814,6 +845,12 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
     case RS2::ActionLayersFreezeAll:
         a = new RS_ActionLayersFreezeAll(true, *document, *view);
         break;
+    case RS2::ActionLayersUnlockAll:
+        a = new RS_ActionLayersLockAll(false, *document, *view);
+        break;
+    case RS2::ActionLayersLockAll:
+        a = new RS_ActionLayersLockAll(true, *document, *view);
+        break;
     case RS2::ActionLayersAdd:
         a = new RS_ActionLayersAdd(*document, *view);
         break;
@@ -869,6 +906,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			a = new RS_ActionSelect(this, *document, *view, RS2::ActionBlocksCreateNoSelect);
 			break;
 		}
+        // fall-through
     case RS2::ActionBlocksCreateNoSelect:
         a = new RS_ActionBlocksCreate(*document, *view);
         break;
@@ -877,6 +915,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 			a = new RS_ActionSelect(this, *document, *view, RS2::ActionBlocksExplodeNoSelect);
 			break;
 		}
+        // fall-through
     case RS2::ActionBlocksExplodeNoSelect:
         a = new RS_ActionBlocksExplode(*document, *view);
         break;
@@ -1077,31 +1116,33 @@ bool QG_ActionHandler::commandLineActions(RS2::ActionType type){
  *         false: the command is not known and was probably intended for a
  *            running action.
  */
-bool QG_ActionHandler::command(const QString& cmd) {
+bool QG_ActionHandler::command(const QString& cmd)
+{
+    if (!view) return false;
+
+    if (cmd.isEmpty())
+    {
+		if (RS_SETTINGS->readNumEntry("/Keyboard/ToggleFreeSnapOnSpace", true))
+			slotSnapFree();
+        return true;
+    }
+
     RS_DEBUG->print("QG_ActionHandler::command: %s", cmd.toLatin1().data());
     QString c = cmd.toLower();
 
-    if (c=="\n" || c==tr("escape", "escape, go back from action steps")) {
-		if (view) {
-            if(c=="\n" ){
-                view->enter();
-                RS_DEBUG->print("QG_ActionHandler::command: enter");
-            }else{
-                view->back();
-                RS_DEBUG->print("QG_ActionHandler::command: back");
-            }
-        }
+    if (c==tr("escape", "escape, go back from action steps"))
+    {
+        view->back();
+        RS_DEBUG->print("QG_ActionHandler::command: back");
         return true;
     }
 
     // pass command on to running action:
     RS_CommandEvent e(cmd);
 
-	if (view) {
-        RS_DEBUG->print("QG_ActionHandler::command: trigger command event in "
-                        " graphic view");
-        view->commandEvent(&e);
-    }
+    RS_DEBUG->print("QG_ActionHandler::command: trigger command event in "
+                    " graphic view");
+    view->commandEvent(&e);
 
     // if the current action can't deal with the command,
     //   it might be intended to launch a new command
@@ -1380,6 +1421,10 @@ void QG_ActionHandler::slotDrawLinePolygon() {
     setCurrentAction(RS2::ActionDrawLinePolygonCenCor);
 }
 
+void QG_ActionHandler::slotDrawLinePolygon3() {           //20161223 added by txmy
+    setCurrentAction(RS2::ActionDrawLinePolygonCenTan);
+}
+
 void QG_ActionHandler::slotDrawLinePolygon2() {
     setCurrentAction(RS2::ActionDrawLinePolygonCorCor);
 }
@@ -1778,6 +1823,14 @@ void QG_ActionHandler::slotLayersFreezeAll() {
     setCurrentAction(RS2::ActionLayersFreezeAll);
 }
 
+void QG_ActionHandler::slotLayersUnlockAll() {
+    setCurrentAction(RS2::ActionLayersUnlockAll);
+}
+
+void QG_ActionHandler::slotLayersLockAll() {
+    setCurrentAction(RS2::ActionLayersLockAll);
+}
+
 void QG_ActionHandler::slotLayersAdd() {
     setCurrentAction(RS2::ActionLayersAdd);
 }
